Documentation
¶
Overview ¶
Package revgeo provides a reverse geocoding capability. Latitude and longitude to ISO country code. This package uses GeoJSON polygons. DATASET source: https://datahub.io/core/geo-countries#data-cli
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Asset ¶
Asset loads and returns the asset for the given name. It returns an error if the asset could not be found or could not be loaded.
func AssetDir ¶
AssetDir returns the file names below a certain directory embedded in the file by go-bindata. For example if you run go-bindata on data/... and data contains the following hierarchy:
data/
foo.txt
img/
a.png
b.png
then AssetDir("data") would return []string{"foo.txt", "img"} AssetDir("data/img") would return []string{"a.png", "b.png"} AssetDir("foo.txt") and AssetDir("notexist") would return an error AssetDir("") will return []string{"data"}.
func AssetInfo ¶
AssetInfo loads and returns the asset info for the given name. It returns an error if the asset could not be found or could not be loaded.
func MustAsset ¶
MustAsset is like Asset but panics when Asset would return an error. It simplifies safe initialization of global variables.
func RestoreAsset ¶
RestoreAsset restores an asset under the given directory
func RestoreAssets ¶
RestoreAssets restores an asset under the given directory recursively
Types ¶
type Decoder ¶
type Decoder struct {
// contains filtered or unexported fields
}
Decoder holds gemetry in memory and provides method Geocode()
Example (Geocode) ¶
decoder := Decoder{}
var lat float64
var lng float64
lat = 48.75181328781114
lng = 16.234285804999985
country, err := decoder.Geocode(lng, lat)
if err != nil {
log.Panicln(err)
}
fmt.Println(country)
Output: CZE